<?php
/**
 * Created by PhpStorm.
 * User: eugeniofonseca
 * Date: 18/08/14
 * Time: 13:54
 */

namespace Service;


class CostResource {

    private $entityManager;
    private $costResourceFactory;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager, \Factory\CostResource $costResourceFactory) {
        $this->entityManager = $entityManager;
        $this->costResourceFactory = $costResourceFactory;
    }

    public function parseDate($date){
        if($date != null || !empty($date)){
            $date = str_replace('/', '-', $date);
            return new \DateTime($date);
        }
        return null;
    }

    public function parseAllDays($boolValue){
        return $boolValue ? 'A' : 'I';
    }
    protected function findCostForCreateCost($effectiveDate,$allDays,$resource){
        if($allDays == 'I'){
            $costs = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\CostResource')->findBy(array("effectiveDate" => $effectiveDate, 'resource' => $resource));
        }else if($allDays == 'A'){
            $costs = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\CostResource')->findBy(array("everyDay" => $allDays, 'resource' => $resource));
        }
        return $costs;
    }
    public function persistResourceCosts($defaultTax, $hourCost, $extraHourTax, $effectiveDate, $allDays, $resource) {
        $entities = array();

        $effectiveDate = $this->parseDate($effectiveDate);
        $allDays = $this->parseAllDays($allDays);
        /** @var \Zeedhi\DevOps\Model\Projectmanagement\Entities\CostResource[] $costs */
        $costs = $this->findCostForCreateCost($effectiveDate, $allDays, $resource);
        if(empty($costs)){
            if(!empty($defaultTax)){
                $entities[0] = $this->costResourceFactory->createCost(
                    $resource,
                    $effectiveDate,
                    "A",
                    "D",
                    $defaultTax,
                    $allDays
                );
            }

            if(!empty($extraHourTax)){
                $entities[1] = $this->costResourceFactory->createCost(
                    $resource,
                    $effectiveDate,
                    "A",
                    "E",
                    $extraHourTax,
                    $allDays
                );
            }

            if(!empty($hourCost)){
                $entities[2] = $this->costResourceFactory->createCost(
                    $resource,
                    $effectiveDate,
                    "A",
                    "H",
                    $hourCost,
                    $allDays
                );
            }
        }else{
            foreach($costs as $cost){
                if((!empty($defaultTax)) and ($cost->getRateType() == 'D')){
                    $entities[0] = $this->costResourceFactory->updateCost(
                        $resource,
                        $effectiveDate,
                        "A",
                        "D",
                        $defaultTax,
                        $allDays,
                        $cost
                    );
                }

                if((!empty($extraHourTax))  and ($cost->getRateType() == 'E')){
                    $entities[1] = $this->costResourceFactory->updateCost(
                        $resource,
                        $effectiveDate,
                        "A",
                        "E",
                        $extraHourTax,
                        $allDays,
                        $cost
                    );
                }

                if((!empty($hourCost))  and ($cost->getRateType() == 'H')){
                    $entities[2] = $this->costResourceFactory->updateCost(
                        $resource,
                        $effectiveDate,
                        "A",
                        "H",
                        $hourCost,
                        $allDays,
                        $cost

                    );
                }
            }
        }

        foreach($entities as $entity){
            $this->entityManager->persist($entity);
            $this->entityManager->flush();
        }
        return $entities;
    }

    public function deleteCost($param){
        foreach($param as $cost){
            $entity = $this->entityManager->find('\Zeedhi\DevOps\Model\Projectmanagement\Entities\CostResource',$cost['ID']);
            $this->entityManager->remove($entity);
            $this->entityManager->flush();
        }
    }
} 